@@ -1,3 +1,4 @@
+import threading
 from typing import Callable, Type, Any, Union, Tuple
 import functools
 from .Functions import areoneof, isoneof, isoneof_strict
@@ -109,7 +110,7 @@ def PartallyImplemented(func: Callable) -> Callable:
     @functools.wraps(func)
     def wrapper(*args, **kwargs) -> Any:
         print(
-            f"As marked by the developer, {func.__module__}.{func.__qualname__} may not be fully implemented and may not work propely")
+            f"As marked by the developer, {func.__module__}.{func.__qualname__} may not be fully implemented and might not work propely")
         return func(*args, **kwargs)
     return wrapper
 
@@ -281,6 +282,19 @@ def deprecate(obj: Union[str, Callable] = None) -> Callable:
     return wrapper
 
 
+# @PartallyImplemented
+
+
+@validate(Callable)
+def atomic(func):
+    lock = threading.Lock()
+
+    @functools.wraps(func)
+    def wrapper(*args, **kwargs):
+        with lock:
+            return func(*args, **kwargs)
+    return wrapper
+
 # @PartallyImplemented
 # @validate(str, Type, bool, Callable, str)
 # def opt(opt_name: str, opt_type: Type, is_required: bool = True, constraints: Callable[[Any], bool] = None, constraints_description: str = None) -> Callable:
