@@ -1,6 +1,6 @@
 import urllib.request
 import urllib.parse
-from urllib.parse import urlparse, urlencode
+from urllib.parse import urlparse
 from typing import Tuple
 import urllib
 from .Decorators import validate
